Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the gnmic v1alpha1 API group +kubebuilder:object:generate=true +groupName=operator.gnmic.dev
Index ¶
- Variables
- type APIConfig
- type Cluster
- type ClusterList
- type ClusterSpec
- type ClusterStatus
- type ClusterTLSConfig
- type ClusterTargetState
- type ConsulConfig
- type GRPCKeepAliveConfig
- type GRPCTunnelConfig
- type HTTPConfig
- type Input
- type InputList
- type InputSelector
- type InputSpec
- type InputStatus
- type Output
- type OutputList
- type OutputSelector
- type OutputServiceSpec
- type OutputSpec
- type OutputStatus
- type Pipeline
- type PipelineList
- type PipelineSpec
- type PipelineStatus
- type Processor
- type ProcessorList
- type ProcessorSpec
- type ProcessorStatus
- type ServiceConfig
- type ServiceReference
- type ServiceSelector
- type Subscription
- type SubscriptionHistoryConfig
- type SubscriptionList
- type SubscriptionSpec
- type SubscriptionStatus
- type Target
- type TargetList
- type TargetProfile
- type TargetProfileList
- type TargetProfileSpec
- type TargetProfileStatus
- type TargetSource
- type TargetSourceList
- type TargetSourceSpec
- type TargetSourceStatus
- type TargetSpec
- type TargetStatus
- type TargetTLSConfig
- type TunnelTargetPolicy
- type TunnelTargetPolicyList
- type TunnelTargetPolicySpec
- type TunnelTargetPolicyStatus
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "operator.gnmic.dev", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type APIConfig ¶
type APIConfig struct {
// The port for the REST API
// +kubebuilder:default=7890
RestPort int32 `json:"restPort"`
// The port for the gNMI Server
// exposed by the gNMIc pods.
// If not set, the gNMI server is not enabled.
GNMIPort int32 `json:"gnmiPort,omitempty"`
// The TLS configuration for the REST and gNMI servers
// If not set, the TLS is not enabled.
TLS *ClusterTLSConfig `json:"tls,omitempty"`
}
func (*APIConfig) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new APIConfig.
func (*APIConfig) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Cluster ¶
type Cluster struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ClusterSpec `json:"spec,omitempty"`
Status ClusterStatus `json:"status,omitempty"`
}
Cluster is the Schema for the clusters API
func (*Cluster) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Cluster.
func (*Cluster) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Cluster) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterList ¶
type ClusterList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Cluster `json:"items"`
}
ClusterList contains a list of Cluster
func (*ClusterList) DeepCopy ¶
func (in *ClusterList) DeepCopy() *ClusterList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterList.
func (*ClusterList) DeepCopyInto ¶
func (in *ClusterList) DeepCopyInto(out *ClusterList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterList) DeepCopyObject ¶
func (in *ClusterList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterSpec ¶
type ClusterSpec struct {
// The gNMIc image to use
// +kubebuilder:validation:Required
Image string `json:"image"`
// The number of replicas to run
// +kubebuilder:default=1
Replicas *int32 `json:"replicas,omitempty"`
// The REST/gNMI server configuration
API *APIConfig `json:"api,omitempty"`
// The TLS configuration for the gNMI client certificates
// If not set, the gNMI client certificates are not enabled.
ClientTLS *ClusterTLSConfig `json:"clientTLS,omitempty"`
// The gRPC tunnel server endpoint configuration
// If not set, the gRPC tunnel server is not enabled on this cluster.
GRPCTunnel *GRPCTunnelConfig `json:"grpcTunnel,omitempty"`
// The resources requests and limits for the gNMIc pods
Resources corev1.ResourceRequirements `json:"resources,omitempty"`
// Environment variables to set in the gNMIc pods
Env []corev1.EnvVar `json:"env,omitempty"`
}
ClusterSpec defines the desired state of Cluster
func (*ClusterSpec) DeepCopy ¶
func (in *ClusterSpec) DeepCopy() *ClusterSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterSpec.
func (*ClusterSpec) DeepCopyInto ¶
func (in *ClusterSpec) DeepCopyInto(out *ClusterSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterStatus ¶
type ClusterStatus struct {
// The number of ready replicas
ReadyReplicas int32 `json:"readyReplicas"`
// The number of pipelines referencing this cluster
PipelinesCount int32 `json:"pipelinesCount"`
// The number of targets referenced by the pipelines
TargetsCount int32 `json:"targetsCount"`
// The number of subscriptions referenced by the pipelines
SubscriptionsCount int32 `json:"subscriptionsCount"`
// The number of inputs referenced by the pipelines
InputsCount int32 `json:"inputsCount"`
// The number of outputs referenced by the pipelines
OutputsCount int32 `json:"outputsCount"`
// The conditions of the cluster
Conditions []metav1.Condition `json:"conditions,omitempty"`
}
ClusterStatus defines the observed state of Cluster
func (*ClusterStatus) DeepCopy ¶
func (in *ClusterStatus) DeepCopy() *ClusterStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterStatus.
func (*ClusterStatus) DeepCopyInto ¶
func (in *ClusterStatus) DeepCopyInto(out *ClusterStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterTLSConfig ¶
type ClusterTLSConfig struct {
// A CertManager Issuer used to sign the gNMIc pods API or gNMI client certificates.
IssuerRef string `json:"issuerRef,omitempty"`
// Additional trusted CA bundle to mount to the gNMIc pods API or gNMI client certificates.
BundleRef string `json:"bundleRef,omitempty"`
// If true the operator will use CertManager CSI driver to request and mount the pods API or gNMI client certificates.
UseCSIDriver bool `json:"useCSIDriver,omitempty"`
}
TLS configuration for the gNMIc pods API or gNMI client certificates
func (*ClusterTLSConfig) DeepCopy ¶
func (in *ClusterTLSConfig) DeepCopy() *ClusterTLSConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterTLSConfig.
func (*ClusterTLSConfig) DeepCopyInto ¶
func (in *ClusterTLSConfig) DeepCopyInto(out *ClusterTLSConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterTargetState ¶ added in v0.2.0
type ClusterTargetState struct {
// The pod within the cluster that currently owns this target.
Pod string `json:"pod"`
// The target's operational state (starting, running, stopping, stopped, failed).
State string `json:"state,omitempty"`
// The reason for failure when state is "failed".
// +optional
FailedReason string `json:"failedReason,omitempty"`
// The gNMI connection state (CONNECTING, READY, TRANSIENT_FAILURE, etc.).
ConnectionState string `json:"connectionState,omitempty"`
// Per-subscription state (subscription name -> running/stopped).
// +optional
Subscriptions map[string]string `json:"subscriptions,omitempty"`
// When this state was last updated by the gNMIc pod.
LastUpdated metav1.Time `json:"lastUpdated,omitempty"`
}
ClusterTargetState represents the state of a target on a specific gNMIc cluster pod.
func (*ClusterTargetState) DeepCopy ¶ added in v0.2.0
func (in *ClusterTargetState) DeepCopy() *ClusterTargetState
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterTargetState.
func (*ClusterTargetState) DeepCopyInto ¶ added in v0.2.0
func (in *ClusterTargetState) DeepCopyInto(out *ClusterTargetState)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConsulConfig ¶
type ConsulConfig struct {
URL string `json:"url,omitempty"`
}
func (*ConsulConfig) DeepCopy ¶
func (in *ConsulConfig) DeepCopy() *ConsulConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConsulConfig.
func (*ConsulConfig) DeepCopyInto ¶
func (in *ConsulConfig) DeepCopyInto(out *ConsulConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GRPCKeepAliveConfig ¶
type GRPCKeepAliveConfig struct {
// gRPC keep alive time (interval)
Time metav1.Duration `json:"time,omitempty"`
// gRPC keep alive timeout
Timeout metav1.Duration `json:"timeout,omitempty"`
// If true gRPC keepalives are sent when there is no active stream
PermitWithoutStream bool `json:"permitWithoutStream,omitempty"`
}
func (*GRPCKeepAliveConfig) DeepCopy ¶
func (in *GRPCKeepAliveConfig) DeepCopy() *GRPCKeepAliveConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GRPCKeepAliveConfig.
func (*GRPCKeepAliveConfig) DeepCopyInto ¶
func (in *GRPCKeepAliveConfig) DeepCopyInto(out *GRPCKeepAliveConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GRPCTunnelConfig ¶
type GRPCTunnelConfig struct {
// The port for the gRPC tunnel
Port int32 `json:"port"`
// The TLS configuration for the gRPC tunnel
TLS *ClusterTLSConfig `json:"tls,omitempty"`
// The service configuration for the gRPC tunnel that will be exposed to the clients
Service *ServiceConfig `json:"service,omitempty"`
}
func (*GRPCTunnelConfig) DeepCopy ¶
func (in *GRPCTunnelConfig) DeepCopy() *GRPCTunnelConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GRPCTunnelConfig.
func (*GRPCTunnelConfig) DeepCopyInto ¶
func (in *GRPCTunnelConfig) DeepCopyInto(out *GRPCTunnelConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HTTPConfig ¶
type HTTPConfig struct {
URL string `json:"url,omitempty"`
}
func (*HTTPConfig) DeepCopy ¶
func (in *HTTPConfig) DeepCopy() *HTTPConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HTTPConfig.
func (*HTTPConfig) DeepCopyInto ¶
func (in *HTTPConfig) DeepCopyInto(out *HTTPConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Input ¶
type Input struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec InputSpec `json:"spec,omitempty"`
Status InputStatus `json:"status,omitempty"`
}
Input is the Schema for the inputs API
func (*Input) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Input.
func (*Input) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Input) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type InputList ¶
type InputList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Input `json:"items"`
}
InputList contains a list of Input
func (*InputList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InputList.
func (*InputList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*InputList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type InputSelector ¶
type InputSelector struct {
// The selector for the inputs
InputSelectors []metav1.LabelSelector `json:"inputSelectors,omitempty"`
// The inputs to assign to the pipeline
InputRefs []string `json:"inputRefs,omitempty"`
// The selector for the processors
ProcessorSelectors []metav1.LabelSelector `json:"processorSelectors,omitempty"`
// The processors to assign to the pipeline
ProcessorRefs []string `json:"processorRefs,omitempty"`
}
func (*InputSelector) DeepCopy ¶
func (in *InputSelector) DeepCopy() *InputSelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InputSelector.
func (*InputSelector) DeepCopyInto ¶
func (in *InputSelector) DeepCopyInto(out *InputSelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InputSpec ¶
type InputSpec struct {
// The type of the input
// supported types:
// "kafka", "nats" or "jetstream"
// +kubebuilder:validation:Enum=kafka;nats;jetstream
Type string `json:"type"`
// Config is the input-specific config object.
// Use x-kubernetes-preserve-unknown-fields so each output type can carry its own schema.
// +kubebuilder:pruning:PreserveUnknownFields
// +kubebuilder:validation:Schemaless
Config apiextensionsv1.JSON `json:"config,omitempty"`
}
InputSpec defines the desired state of Input
func (*InputSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InputSpec.
func (*InputSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InputStatus ¶
type InputStatus struct {
}
InputStatus defines the observed state of Input
func (*InputStatus) DeepCopy ¶
func (in *InputStatus) DeepCopy() *InputStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InputStatus.
func (*InputStatus) DeepCopyInto ¶
func (in *InputStatus) DeepCopyInto(out *InputStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Output ¶
type Output struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec OutputSpec `json:"spec,omitempty"`
Status OutputStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:storageversion +kubebuilder:subresource:status +kubebuilder:printcolumn:name="Type",type=string,JSONPath=`.spec.type` Output is the Schema for the outputs API
func (*Output) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Output.
func (*Output) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Output) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type OutputList ¶
type OutputList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Output `json:"items"`
}
OutputList contains a list of Output
func (*OutputList) DeepCopy ¶
func (in *OutputList) DeepCopy() *OutputList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OutputList.
func (*OutputList) DeepCopyInto ¶
func (in *OutputList) DeepCopyInto(out *OutputList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*OutputList) DeepCopyObject ¶
func (in *OutputList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type OutputSelector ¶
type OutputSelector struct {
// The selector for the outputs
OutputSelectors []metav1.LabelSelector `json:"outputSelectors,omitempty"`
// The outputs to assign to the pipeline
OutputRefs []string `json:"outputRefs,omitempty"`
// The selector for the processors
ProcessorSelectors []metav1.LabelSelector `json:"processorSelectors,omitempty"`
// The processors to assign to the pipeline
ProcessorRefs []string `json:"processorRefs,omitempty"`
}
func (*OutputSelector) DeepCopy ¶
func (in *OutputSelector) DeepCopy() *OutputSelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OutputSelector.
func (*OutputSelector) DeepCopyInto ¶
func (in *OutputSelector) DeepCopyInto(out *OutputSelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OutputServiceSpec ¶
type OutputServiceSpec struct {
// Type specifies the Kubernetes service type (ClusterIP, NodePort, LoadBalancer)
// +kubebuilder:validation:Enum=ClusterIP;NodePort;LoadBalancer
// +kubebuilder:default=ClusterIP
// +optional
Type corev1.ServiceType `json:"type,omitempty"`
// Annotations to add to the service
// +optional
Annotations map[string]string `json:"annotations,omitempty"`
// Labels to add to the service
// +optional
Labels map[string]string `json:"labels,omitempty"`
}
OutputServiceSpec defines the service configuration for outputs that expose an endpoint
func (*OutputServiceSpec) DeepCopy ¶
func (in *OutputServiceSpec) DeepCopy() *OutputServiceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OutputServiceSpec.
func (*OutputServiceSpec) DeepCopyInto ¶
func (in *OutputServiceSpec) DeepCopyInto(out *OutputServiceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OutputSpec ¶
type OutputSpec struct {
// The output type
// +kubebuilder:validation:Enum=file;kafka;prometheus;prometheus_write;nats;jetstream;influxdb;tcp;udp
Type string `json:"type"`
// The output-specific config object.
// +kubebuilder:pruning:PreserveUnknownFields
// +kubebuilder:validation:Schemaless
Config apiextensionsv1.JSON `json:"config,omitempty"`
// The service configuration for outputs that expose an endpoint (Prometheus).
// If not specified, a ClusterIP service will be created by default.
// +optional
Service *OutputServiceSpec `json:"service,omitempty"`
// ServiceRef references a Kubernetes Service to use as the output address.
// Supported for: nats, jetstream, kafka outputs.
// The service address will be resolved and injected into the output config.
// +optional
ServiceRef *ServiceReference `json:"serviceRef,omitempty"`
// ServiceSelector selects Kubernetes Services by labels to use as output addresses.
// Supported for: nats, jetstream, kafka outputs.
// All matching service addresses will be resolved and injected into the output config.
// +optional
ServiceSelector *ServiceSelector `json:"serviceSelector,omitempty"`
}
OutputSpec defines the desired state of Output
func (*OutputSpec) DeepCopy ¶
func (in *OutputSpec) DeepCopy() *OutputSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OutputSpec.
func (*OutputSpec) DeepCopyInto ¶
func (in *OutputSpec) DeepCopyInto(out *OutputSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OutputStatus ¶
type OutputStatus struct {
}
OutputStatus defines the observed state of Output
func (*OutputStatus) DeepCopy ¶
func (in *OutputStatus) DeepCopy() *OutputStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OutputStatus.
func (*OutputStatus) DeepCopyInto ¶
func (in *OutputStatus) DeepCopyInto(out *OutputStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Pipeline ¶
type Pipeline struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PipelineSpec `json:"spec,omitempty"`
Status PipelineStatus `json:"status,omitempty"`
}
Pipeline is the Schema for the pipelines API
func (*Pipeline) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Pipeline.
func (*Pipeline) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Pipeline) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PipelineList ¶
type PipelineList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Pipeline `json:"items"`
}
PipelineList contains a list of Pipeline
func (*PipelineList) DeepCopy ¶
func (in *PipelineList) DeepCopy() *PipelineList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineList.
func (*PipelineList) DeepCopyInto ¶
func (in *PipelineList) DeepCopyInto(out *PipelineList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PipelineList) DeepCopyObject ¶
func (in *PipelineList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PipelineSpec ¶
type PipelineSpec struct {
// The cluster to assign the pipeline to
ClusterRef string `json:"clusterRef"`
// Whether the pipeline is enabled
Enabled bool `json:"enabled,omitempty"`
// The selector for the targets
TargetSelectors []metav1.LabelSelector `json:"targetSelectors,omitempty"`
// The targets to assign to the pipeline
TargetRefs []string `json:"targetRefs,omitempty"`
// The selector for the gRPC tunnel target policies
TunnelTargetPolicySelectors []metav1.LabelSelector `json:"tunnelTargetPolicySelectors,omitempty"`
// The gRPC tunnel target policies to assign to the pipeline
TunnelTargetPolicyRefs []string `json:"tunnelTargetPolicyRefs,omitempty"`
// The selector for the subscriptions
SubscriptionSelectors []metav1.LabelSelector `json:"subscriptionSelectors,omitempty"`
// The subscriptions to assign to the pipeline
SubscriptionRefs []string `json:"subscriptionRefs,omitempty"`
// The selector for the outputs
Outputs OutputSelector `json:"outputs,omitempty"`
// The selector for the inputs
Inputs InputSelector `json:"inputs,omitempty"`
// The labels to add to the exported data
Labels map[string]string `json:"labels,omitempty"`
}
PipelineSpec defines the desired state of Pipeline
func (*PipelineSpec) DeepCopy ¶
func (in *PipelineSpec) DeepCopy() *PipelineSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineSpec.
func (*PipelineSpec) DeepCopyInto ¶
func (in *PipelineSpec) DeepCopyInto(out *PipelineSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineStatus ¶
type PipelineStatus struct {
Status string `json:"status"`
TargetsCount int32 `json:"targetsCount"`
SubscriptionsCount int32 `json:"subscriptionsCount"`
InputsCount int32 `json:"inputsCount"`
OutputsCount int32 `json:"outputsCount"`
TunnelTargetPoliciesCount int32 `json:"tunnelTargetPoliciesCount"`
Conditions []metav1.Condition `json:"conditions,omitempty"`
}
PipelineStatus defines the observed state of Pipeline
func (*PipelineStatus) DeepCopy ¶
func (in *PipelineStatus) DeepCopy() *PipelineStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineStatus.
func (*PipelineStatus) DeepCopyInto ¶
func (in *PipelineStatus) DeepCopyInto(out *PipelineStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Processor ¶
type Processor struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ProcessorSpec `json:"spec,omitempty"`
Status ProcessorStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:storageversion +kubebuilder:subresource:status +kubebuilder:printcolumn:name="Type",type=string,JSONPath=`.spec.type` Processor is the Schema for the processors API
func (*Processor) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Processor.
func (*Processor) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Processor) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ProcessorList ¶
type ProcessorList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Processor `json:"items"`
}
ProcessorList contains a list of Processor
func (*ProcessorList) DeepCopy ¶
func (in *ProcessorList) DeepCopy() *ProcessorList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProcessorList.
func (*ProcessorList) DeepCopyInto ¶
func (in *ProcessorList) DeepCopyInto(out *ProcessorList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ProcessorList) DeepCopyObject ¶
func (in *ProcessorList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ProcessorSpec ¶
type ProcessorSpec struct {
// The type of the processor
// +kubebuilder:validation:Enum=event-add-tag;event-allow;event-combine;event-convert;event-data-convert;event-date-string;event-delete;event-drop;event-duration-convert;event-extract-tags;event-group-by;event-ieee-float32;event-jq;event-merge;event-override-ts;event-plugin;event-rate-limit;event-starlark;event-strings;event-time-epoch;event-to-tag;event-trigger;event-value-tag;event-write;
Type string `json:"type"`
// Config is the processor-specific config object.
// Use x-kubernetes-preserve-unknown-fields so each processor type can carry its own schema.
// +kubebuilder:pruning:PreserveUnknownFields
// +kubebuilder:validation:Schemaless
Config apiextensionsv1.JSON `json:"config,omitempty"`
}
ProcessorSpec defines the desired state of Processor
func (*ProcessorSpec) DeepCopy ¶
func (in *ProcessorSpec) DeepCopy() *ProcessorSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProcessorSpec.
func (*ProcessorSpec) DeepCopyInto ¶
func (in *ProcessorSpec) DeepCopyInto(out *ProcessorSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProcessorStatus ¶
type ProcessorStatus struct {
}
ProcessorStatus defines the observed state of Processor
func (*ProcessorStatus) DeepCopy ¶
func (in *ProcessorStatus) DeepCopy() *ProcessorStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProcessorStatus.
func (*ProcessorStatus) DeepCopyInto ¶
func (in *ProcessorStatus) DeepCopyInto(out *ProcessorStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServiceConfig ¶
type ServiceConfig struct {
// Type specifies the Kubernetes service type (ClusterIP, NodePort, LoadBalancer)
// +kubebuilder:validation:Enum=ClusterIP;NodePort;LoadBalancer
// +kubebuilder:default=LoadBalancer
// +optional
Type corev1.ServiceType `json:"type,omitempty"`
// Annotations to add to the service
// +optional
Annotations map[string]string `json:"annotations,omitempty"`
// Labels to add to the service
// +optional
Labels map[string]string `json:"labels,omitempty"`
}
func (*ServiceConfig) DeepCopy ¶
func (in *ServiceConfig) DeepCopy() *ServiceConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceConfig.
func (*ServiceConfig) DeepCopyInto ¶
func (in *ServiceConfig) DeepCopyInto(out *ServiceConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServiceReference ¶
type ServiceReference struct {
// Name of the Service
Name string `json:"name"`
// Namespace of the Service. Defaults to the Output's namespace if not specified.
// +optional
Namespace string `json:"namespace,omitempty"`
// Port is the name or number of the port to use.
// If not specified, the first port of the service is used.
// +optional
Port string `json:"port,omitempty"`
}
ServiceReference references a specific Kubernetes Service
func (*ServiceReference) DeepCopy ¶
func (in *ServiceReference) DeepCopy() *ServiceReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceReference.
func (*ServiceReference) DeepCopyInto ¶
func (in *ServiceReference) DeepCopyInto(out *ServiceReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ServiceSelector ¶
type ServiceSelector struct {
// MatchLabels is a map of {key,value} pairs to match services
MatchLabels map[string]string `json:"matchLabels"`
// Namespace to search for services. Defaults to the Output's namespace if not specified.
// +optional
Namespace string `json:"namespace,omitempty"`
// Port is the name or number of the port to use.
// If not specified, the first port of the service is used.
// +optional
Port string `json:"port,omitempty"`
}
ServiceSelector selects Services by labels
func (*ServiceSelector) DeepCopy ¶
func (in *ServiceSelector) DeepCopy() *ServiceSelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceSelector.
func (*ServiceSelector) DeepCopyInto ¶
func (in *ServiceSelector) DeepCopyInto(out *ServiceSelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Subscription ¶
type Subscription struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec SubscriptionSpec `json:"spec,omitempty"`
Status SubscriptionStatus `json:"status,omitempty"`
}
Subscription is the Schema for the subscriptions API
func (*Subscription) DeepCopy ¶
func (in *Subscription) DeepCopy() *Subscription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Subscription.
func (*Subscription) DeepCopyInto ¶
func (in *Subscription) DeepCopyInto(out *Subscription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Subscription) DeepCopyObject ¶
func (in *Subscription) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SubscriptionHistoryConfig ¶ added in v0.2.0
type SubscriptionHistoryConfig struct {
// The gNMI Subscription history snapshot time
Snapshot metav1.Time `json:"snapshot,omitempty"`
// The gNMI Subscription history start time
Start metav1.Time `json:"start,omitempty"`
// The gNMI Subscription history end time
End metav1.Time `json:"end,omitempty"`
}
func (*SubscriptionHistoryConfig) DeepCopy ¶ added in v0.2.0
func (in *SubscriptionHistoryConfig) DeepCopy() *SubscriptionHistoryConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubscriptionHistoryConfig.
func (*SubscriptionHistoryConfig) DeepCopyInto ¶ added in v0.2.0
func (in *SubscriptionHistoryConfig) DeepCopyInto(out *SubscriptionHistoryConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SubscriptionList ¶
type SubscriptionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Subscription `json:"items"`
}
SubscriptionList contains a list of Subscription
func (*SubscriptionList) DeepCopy ¶
func (in *SubscriptionList) DeepCopy() *SubscriptionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubscriptionList.
func (*SubscriptionList) DeepCopyInto ¶
func (in *SubscriptionList) DeepCopyInto(out *SubscriptionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SubscriptionList) DeepCopyObject ¶
func (in *SubscriptionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SubscriptionSpec ¶
type SubscriptionSpec struct {
// The gNMI prefix to subscribe to
Prefix string `json:"prefix,omitempty"`
// The gNMI target to subscribe to
Target string `json:"target,omitempty"`
// The gNMI paths to subscribe to
Paths []string `json:"paths,omitempty"`
// The gNMI SubscriptionList mode (ONCE, STREAM/SAMPLE, STREAM/ON_CHANGE, STREAM/TARGET_DEFINED or POLL)
// +kubebuilder:validation:Enum=ONCE;STREAM;STREAM/SAMPLE;STREAM/ON_CHANGE;STREAM/TARGET_DEFINED;POLL
Mode string `json:"mode,omitempty"`
// The gNMI Subscription sample interval
SampleInterval metav1.Duration `json:"sampleInterval,omitempty"`
// The gNMI Subscription heartbeat interval
HeartbeatInterval metav1.Duration `json:"heartbeatInterval,omitempty"`
// Whether to only send updates or all data
UpdatesOnly bool `json:"updatesOnly,omitempty"`
// The gNMI Subscription stream subscriptions
StreamSubscriptions []string `json:"streamSubscriptions,omitempty"`
// The gNMI Subscription depth (Depth extension)
Depth uint32 `json:"depth,omitempty"`
// The gNMI Subscription encoding (JSON, BYTES, PROTO, ASCII, JSON_IETF)
// +kubebuilder:validation:Enum=JSON;BYTES;PROTO;ASCII;JSON_IETF
Encoding string `json:"encoding,omitempty"`
// The gNMI Subscription QoS (0-9)
Qos *uint32 `json:"qos,omitempty"`
// Whether to suppress redundant updates
SuppressRedundant bool `json:"suppressRedundant,omitempty"`
// The gNMI Subscription history configuration
History *SubscriptionHistoryConfig `json:"history,omitempty"`
}
SubscriptionSpec defines the desired state of Subscription
func (*SubscriptionSpec) DeepCopy ¶
func (in *SubscriptionSpec) DeepCopy() *SubscriptionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubscriptionSpec.
func (*SubscriptionSpec) DeepCopyInto ¶
func (in *SubscriptionSpec) DeepCopyInto(out *SubscriptionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SubscriptionStatus ¶
type SubscriptionStatus struct {
}
SubscriptionStatus defines the observed state of Subscription
func (*SubscriptionStatus) DeepCopy ¶
func (in *SubscriptionStatus) DeepCopy() *SubscriptionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SubscriptionStatus.
func (*SubscriptionStatus) DeepCopyInto ¶
func (in *SubscriptionStatus) DeepCopyInto(out *SubscriptionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Target ¶
type Target struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec TargetSpec `json:"spec,omitempty"`
Status TargetStatus `json:"status,omitempty"`
}
Target is the Schema for the targets API
func (*Target) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Target.
func (*Target) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Target) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TargetList ¶
type TargetList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Target `json:"items"`
}
TargetList contains a list of Target
func (*TargetList) DeepCopy ¶
func (in *TargetList) DeepCopy() *TargetList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetList.
func (*TargetList) DeepCopyInto ¶
func (in *TargetList) DeepCopyInto(out *TargetList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TargetList) DeepCopyObject ¶
func (in *TargetList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TargetProfile ¶
type TargetProfile struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec TargetProfileSpec `json:"spec,omitempty"`
Status TargetProfileStatus `json:"status,omitempty"`
}
TargetProfile is the Schema for the targetprofiles API
func (*TargetProfile) DeepCopy ¶
func (in *TargetProfile) DeepCopy() *TargetProfile
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetProfile.
func (*TargetProfile) DeepCopyInto ¶
func (in *TargetProfile) DeepCopyInto(out *TargetProfile)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TargetProfile) DeepCopyObject ¶
func (in *TargetProfile) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TargetProfileList ¶
type TargetProfileList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []TargetProfile `json:"items"`
}
TargetProfileList contains a list of TargetProfile
func (*TargetProfileList) DeepCopy ¶
func (in *TargetProfileList) DeepCopy() *TargetProfileList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetProfileList.
func (*TargetProfileList) DeepCopyInto ¶
func (in *TargetProfileList) DeepCopyInto(out *TargetProfileList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TargetProfileList) DeepCopyObject ¶
func (in *TargetProfileList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TargetProfileSpec ¶
type TargetProfileSpec struct {
// The credentials of the target
// username, password or token keys in the secret referenced by the field
CredentialsRef string `json:"credentialsRef,omitempty"`
// Target TLS configuration
TLS *TargetTLSConfig `json:"tls,omitempty"`
// Target connection timeout
// +kubebuilder:default="10s"
Timeout metav1.Duration `json:"timeout,omitempty"`
// default is 2 seconds
// +kubebuilder:default="2s"
// +kubebuilder:validation:XValidation:rule="self == ” || duration(self) >= duration('2s')",message="RetryTimer must be at least 2 seconds"
RetryTimer metav1.Duration `json:"retryTimer,omitempty"`
// The gNMI Subscription encoding (JSON, BYTES, PROTO, ASCII, JSON_IETF)
// +kubebuilder:validation:Enum=JSON;BYTES;PROTO;ASCII;JSON_IETF
// +kubebuilder:default="JSON"
Encoding string `json:"encoding,omitempty"`
// The labels to add to the target's updates
Labels map[string]string `json:"labels,omitempty"`
// The proxy to use to connect to the target
Proxy string `json:"proxy,omitempty"`
// Whether to use gzip compression
GzipCompression bool `json:"gzipCompression,omitempty"`
// The TCP keep-alive interval
TCPKeepAlive *metav1.Duration `json:"tcpKeepAlive,omitempty"`
// The gRPC keep-alive configuration
GRCPKeepAlive *GRPCKeepAliveConfig `json:"grpcKeepAlive,omitempty"`
}
TargetProfileSpec defines the desired state of TargetProfile
func (*TargetProfileSpec) DeepCopy ¶
func (in *TargetProfileSpec) DeepCopy() *TargetProfileSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetProfileSpec.
func (*TargetProfileSpec) DeepCopyInto ¶
func (in *TargetProfileSpec) DeepCopyInto(out *TargetProfileSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TargetProfileStatus ¶
type TargetProfileStatus struct {
}
TargetProfileStatus defines the observed state of TargetProfile
func (*TargetProfileStatus) DeepCopy ¶
func (in *TargetProfileStatus) DeepCopy() *TargetProfileStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetProfileStatus.
func (*TargetProfileStatus) DeepCopyInto ¶
func (in *TargetProfileStatus) DeepCopyInto(out *TargetProfileStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TargetSource ¶
type TargetSource struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec TargetSourceSpec `json:"spec,omitempty"`
Status TargetSourceStatus `json:"status,omitempty"`
}
TargetSource is the Schema for the targetsources API
func (*TargetSource) DeepCopy ¶
func (in *TargetSource) DeepCopy() *TargetSource
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetSource.
func (*TargetSource) DeepCopyInto ¶
func (in *TargetSource) DeepCopyInto(out *TargetSource)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TargetSource) DeepCopyObject ¶
func (in *TargetSource) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TargetSourceList ¶
type TargetSourceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []TargetSource `json:"items"`
}
TargetSourceList contains a list of TargetSource
func (*TargetSourceList) DeepCopy ¶
func (in *TargetSourceList) DeepCopy() *TargetSourceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetSourceList.
func (*TargetSourceList) DeepCopyInto ¶
func (in *TargetSourceList) DeepCopyInto(out *TargetSourceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TargetSourceList) DeepCopyObject ¶
func (in *TargetSourceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TargetSourceSpec ¶
type TargetSourceSpec struct {
HTTP *HTTPConfig `json:"http,omitempty"`
Consul *ConsulConfig `json:"consul,omitempty"`
ConfigMap string `json:"configMap,omitempty"`
PodSelector metav1.LabelSelector `json:"podSelector,omitempty"`
ServiceSelector metav1.LabelSelector `json:"serviceSelector,omitempty"`
//
Labels map[string]string `json:"labels,omitempty"`
}
TargetSourceSpec defines the desired state of TargetSource
func (*TargetSourceSpec) DeepCopy ¶
func (in *TargetSourceSpec) DeepCopy() *TargetSourceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetSourceSpec.
func (*TargetSourceSpec) DeepCopyInto ¶
func (in *TargetSourceSpec) DeepCopyInto(out *TargetSourceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TargetSourceStatus ¶
type TargetSourceStatus struct {
Status string `json:"status"`
TargetsCount int32 `json:"targetsCount"`
LastSync metav1.Time `json:"lastSync"`
}
TargetSourceStatus defines the observed state of TargetSource
func (*TargetSourceStatus) DeepCopy ¶
func (in *TargetSourceStatus) DeepCopy() *TargetSourceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetSourceStatus.
func (*TargetSourceStatus) DeepCopyInto ¶
func (in *TargetSourceStatus) DeepCopyInto(out *TargetSourceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TargetSpec ¶
type TargetSpec struct {
// The address of the target
Address string `json:"address"`
// The profile to use for the target
Profile string `json:"profile"`
}
TargetSpec defines the desired state of Target
func (*TargetSpec) DeepCopy ¶
func (in *TargetSpec) DeepCopy() *TargetSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetSpec.
func (*TargetSpec) DeepCopyInto ¶
func (in *TargetSpec) DeepCopyInto(out *TargetSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TargetStatus ¶
type TargetStatus struct {
// Number of clusters currently collecting this target.
Clusters int32 `json:"clusters"`
// Aggregate state across all clusters.
// READY if all clusters report running and READY, DEGRADED if any do not.
// Empty when no clusters are collecting this target.
State string `json:"connectionState,omitempty"`
// Per-cluster target state, keyed by Cluster CR name.
// A target may be collected by multiple clusters (via different pipelines).
// +optional
ClusterStates map[string]ClusterTargetState `json:"clusterStates,omitempty"`
}
TargetStatus defines the observed state of Target. A single Target may be collected by multiple Clusters (via different Pipelines), so the status is reported per-cluster.
func (*TargetStatus) DeepCopy ¶
func (in *TargetStatus) DeepCopy() *TargetStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetStatus.
func (*TargetStatus) DeepCopyInto ¶
func (in *TargetStatus) DeepCopyInto(out *TargetStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TargetTLSConfig ¶
type TargetTLSConfig struct {
// TLS serverName override value
ServerName string `json:"serverName,omitempty"`
// TLS Maximum version: 1.1, 1.2 or 1.3
MaxVersion string `json:"maxVersion,omitempty"`
// TLS Minimum version: 1.1, 1.2 or 1.3
MinVersion string `json:"minVersion,omitempty"`
// List of supported TLS cipher suites
CipherSuites []string `json:"cipherSuites,omitempty"`
}
func (*TargetTLSConfig) DeepCopy ¶
func (in *TargetTLSConfig) DeepCopy() *TargetTLSConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TargetTLSConfig.
func (*TargetTLSConfig) DeepCopyInto ¶
func (in *TargetTLSConfig) DeepCopyInto(out *TargetTLSConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TunnelTargetPolicy ¶
type TunnelTargetPolicy struct {
metav1.TypeMeta `json:",inline"`
// metadata is a standard object metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitzero"`
// spec defines the desired state of TunnelTargetPolicy
// +required
Spec TunnelTargetPolicySpec `json:"spec"`
// status defines the observed state of TunnelTargetPolicy
// +optional
Status TunnelTargetPolicyStatus `json:"status,omitzero"`
}
TunnelTargetPolicy is the Schema for the tunneltargetpolicies API
func (*TunnelTargetPolicy) DeepCopy ¶
func (in *TunnelTargetPolicy) DeepCopy() *TunnelTargetPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TunnelTargetPolicy.
func (*TunnelTargetPolicy) DeepCopyInto ¶
func (in *TunnelTargetPolicy) DeepCopyInto(out *TunnelTargetPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TunnelTargetPolicy) DeepCopyObject ¶
func (in *TunnelTargetPolicy) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*TunnelTargetPolicy) Hub ¶
func (*TunnelTargetPolicy) Hub()
Hub marks this type as a conversion hub.
type TunnelTargetPolicyList ¶
type TunnelTargetPolicyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitzero"`
Items []TunnelTargetPolicy `json:"items"`
}
TunnelTargetPolicyList contains a list of TunnelTargetPolicy
func (*TunnelTargetPolicyList) DeepCopy ¶
func (in *TunnelTargetPolicyList) DeepCopy() *TunnelTargetPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TunnelTargetPolicyList.
func (*TunnelTargetPolicyList) DeepCopyInto ¶
func (in *TunnelTargetPolicyList) DeepCopyInto(out *TunnelTargetPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TunnelTargetPolicyList) DeepCopyObject ¶
func (in *TunnelTargetPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type TunnelTargetPolicySpec ¶
type TunnelTargetPolicySpec struct {
// The match criteria for the target
// Not required, if not set, the policy will match all targets.
Match *tunnelTargetMatch `json:"match,omitempty"`
// The target profile to use for the matching targets
// kubebuilder:validation:Required
Profile string `json:"profile"`
}
TunnelTargetPolicySpec defines the desired state of TunnelTargetPolicy
func (*TunnelTargetPolicySpec) DeepCopy ¶
func (in *TunnelTargetPolicySpec) DeepCopy() *TunnelTargetPolicySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TunnelTargetPolicySpec.
func (*TunnelTargetPolicySpec) DeepCopyInto ¶
func (in *TunnelTargetPolicySpec) DeepCopyInto(out *TunnelTargetPolicySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TunnelTargetPolicyStatus ¶
type TunnelTargetPolicyStatus struct {
}
TunnelTargetPolicyStatus defines the observed state of TunnelTargetPolicy.
func (*TunnelTargetPolicyStatus) DeepCopy ¶
func (in *TunnelTargetPolicyStatus) DeepCopy() *TunnelTargetPolicyStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TunnelTargetPolicyStatus.
func (*TunnelTargetPolicyStatus) DeepCopyInto ¶
func (in *TunnelTargetPolicyStatus) DeepCopyInto(out *TunnelTargetPolicyStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
Source Files
¶
- cluster_conversion.go
- cluster_types.go
- groupversion_info.go
- input_conversion.go
- input_types.go
- output_conversion.go
- output_types.go
- pipeline_conversion.go
- pipeline_types.go
- processor_conversion.go
- processor_types.go
- subscription_conversion.go
- subscription_types.go
- target_conversion.go
- target_types.go
- targetprofile_conversion.go
- targetprofile_types.go
- targetsource_conversion.go
- targetsource_types.go
- tunneltargetpolicy_conversion.go
- tunneltargetpolicy_types.go
- zz_generated.deepcopy.go